From: Andreas Joseph Krogh <andreas@visena.com>
To: pgsql-hackers@lists.postgresql.org
Subject: Sv: Re: Query is over 2x slower with jit=on
Date: Wed, 18 Apr 2018 18:26:03 +0200 (CEST)
Message-ID: <VisenaEmail.27.2a4e4d7bcb66442e.162d991746c@tc7-visena> (raw)
In-Reply-To: <20180418155055.gawfkerzvy5rxpxe@alap3.anarazel.de>
På onsdag 18. april 2018 kl. 17:50:55, skrev Andres Freund <andres@anarazel.de
<mailto:andres@anarazel.de>>:
On 2018-04-18 17:35:31 +0200, Andreas Joseph Krogh wrote:
> With jit=on:
> https://explain.depesz.com/s/vYB
> Planning Time: 0.336 ms
> JIT:
> Functions: 716
> Generation Time: 78.404 ms
> Inlining: false
> Inlining Time: 0.000 ms
> Optimization: false
> Optimization Time: 43.916 ms
> Emission Time: 600.031 ms
Any chance this is a debug LLVM build?
> What's the deal with jit making it slower?
JIT has cost, and sometimes it's not beneficial. Here our heuristics
when to JIT appear to be a bit off. In the parallel world it's worse
because the JITing is duplicated for parallel workers atm.
PostgreSQL is built with "--enable-debug --with-llvm". LLVM is the one which
comes with Ubuntu-17.10.
-- Andreas Joseph Krogh
CTO / Partner - Visena AS
Mobile: +47 909 56 963
andreas@visena.com <mailto:andreas@visena.com>
www.visena.com <https://www.visena.com;
<https://www.visena.com;
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: andreas@visena.com, pgsql-hackers@lists.postgresql.org
Subject: Re: Sv: Re: Query is over 2x slower with jit=on
In-Reply-To: <VisenaEmail.27.2a4e4d7bcb66442e.162d991746c@tc7-visena>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox